@@ -5,6 +5,7 @@
  *
  */
 
+#include "config.h"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -16,15 +17,19 @@
 #include <sys/wait.h>
 #include <sys/stat.h>
 #include <signal.h>
-#include "ncplib.h"
+#include <string.h>
+#include <ncp/ncplib.h>
+
+#include <libintl.h>
+#define _(X) gettext(X)
 
 struct nw_queue
 {
 	struct ncp_conn *conn;
 
 	char queue_name[NCP_BINDERY_NAME_LEN];
-	__u32 queue_id;
-	__u16 job_type;
+	u_int32_t queue_id;
+	u_int16_t job_type;
 
 	char *command;
 };
@@ -44,16 +49,16 @@ static int
 static void
 usage(void)
 {
-	fprintf(stderr, "usage: %s [options] file\n", progname);
+	fprintf(stderr, _("usage: %s [options] file\n"), progname);
 	exit(1);
 }
 
 static void
 help(void)
 {
-	printf("\n");
-	printf("usage: %s [options]\n", progname);
-	printf("\n"
+	printf(_("\n"
+		 "usage: %s [options]\n"), progname);
+	printf(_("\n"
 	       "-S server      Server name to be used\n"
 	       "-U username    Print Server name sent to server\n"
 	       "-P password    Use this password\n"
@@ -65,7 +70,7 @@ help(void)
 	       "-t timeout     Polling interval, default: 30 sec\n"
 	       "-d             Debug: don't daemonize\n"
 	       "-h             print this help text\n"
-	       "\n");
+	       "\n"));
 }
 
 #ifndef NCP_BINDERY_PSERVER
@@ -119,6 +124,10 @@ main(int argc, char *argv[])
 	char default_command[] = "lpr";
 	char *command = default_command;
 
+	setlocale(LC_ALL, "");
+	bindtextdomain(PACKAGE, LOCALEDIR);
+	textdomain(PACKAGE);
+	
 	progname = argv[0];
 
 	for (i = 1; i < argc; i += 1)
@@ -148,7 +157,7 @@ main(int argc, char *argv[])
 	if ((conn = ncp_initialize_as(&argc, argv, 1,
 				      NCP_BINDERY_PSERVER, &err)) == NULL)
 	{
-		com_err(argv[0], err, "when initializing");
+		com_err(argv[0], err, _("when initializing"));
 		return 1;
 	}
 	while ((opt = getopt(argc, argv, "q:c:j:t:dh")) != EOF)
@@ -183,16 +192,15 @@ main(int argc, char *argv[])
 		usage();
 		return -1;
 	}
-	memzero(q);
+	memset(&q, 0, sizeof(q));
 
 	if (queue_name == NULL)
 	{
-		fprintf(stderr, "You must specify a queue\n");
+		fprintf(stderr, _("You must specify a queue\n"));
 		return 1;
 	}
 	if (init_queue(conn, queue_name, command, &q) != 0)
 	{
-		perror("Could not init queue");
 		ncp_close(conn);
 		return 1;
 	}
@@ -227,25 +235,27 @@ init_queue(struct ncp_conn *conn, char *queue_name, char *command,
 	   struct nw_queue *q)
 {
 	struct ncp_bindery_object obj;
+	long err;
 
 	str_upper(queue_name);
 
 	q->conn = conn;
 	q->command = command;
 
-	if (ncp_get_bindery_object_id(conn, NCP_BINDERY_PQUEUE,
-				      queue_name, &obj) != 0)
-	{
-		fprintf(stderr, "Queue %s not found\n", queue_name);
+	err = ncp_get_bindery_object_id(conn, NCP_BINDERY_PQUEUE, 
+					queue_name, &obj);
+	if (err) {
+		fprintf(stderr, _("Queue %s not found: %s\n"), 
+			queue_name, strnwerror(err));
 		return -1;
 	}
 	q->queue_id = obj.object_id;
 	memcpy(q->queue_name, obj.object_name, sizeof(q->queue_name));
 
-	if (ncp_attach_to_queue(conn, q->queue_id) != 0)
-	{
-		fprintf(stderr, "Could not attach to queue %s\n",
-			queue_name);
+	err = ncp_attach_to_queue(conn, q->queue_id);
+	if (err) {
+		fprintf(stderr, _("Could not attach to queue %s: %s\n"),
+			queue_name, strnwerror(err));
 		return -1;
 	}
 	return 0;
@@ -294,7 +304,7 @@ build_command(struct nw_queue *q, struct queue_job *j,
                         if (j->j.JobTextDescription[0])
                                 add_string(j->j.JobTextDescription);
                         else
-                                add_string("No Description");
+                                add_string(_("No Description"));
                         break;
 		default:
 			*target = '%';
@@ -339,17 +349,17 @@ poll_queue(struct nw_queue *q)
 	  } 
 	else
 	  {
-	    sprintf(user,"<Unknown>");
+	    sprintf(user,_("<Unknown>"));
 	  }
 	
 	if (pipe(fd) < 0)
 	{
-		syslog(LOG_ERR, "pipe error: %m");
+		syslog(LOG_ERR, _("pipe error: %m"));
 		goto fail;
 	}
 	if ((pid = fork()) < 0)
 	{
-		syslog(LOG_ERR, "fork error: %m");
+		syslog(LOG_ERR, _("fork error: %m"));
 		goto fail;
 	}
 	if (pid > 0)
@@ -375,7 +385,7 @@ poll_queue(struct nw_queue *q)
 
 		if (waitpid(pid, NULL, 0) < 0)
 		{
-			syslog(LOG_ERR, "waitpid: %m\n");
+			syslog(LOG_ERR, _("waitpid: %m\n"));
 		}
 	} else
 	{
@@ -389,7 +399,7 @@ poll_queue(struct nw_queue *q)
 		{
 			if (dup2(fd[0], STDIN_FILENO) != STDIN_FILENO)
 			{
-				syslog(LOG_ERR, "dup2 error: %m\n");
+				syslog(LOG_ERR, _("dup2 error: %m\n"));
 				close(fd[0]);
 				exit(1);
 			}
@@ -399,7 +409,7 @@ poll_queue(struct nw_queue *q)
 		build_command(q, &job, command, sizeof(command), user);
 
 		execl("/bin/sh", "sh", "-c", command, NULL);
-		syslog(LOG_ERR, "exec error: %m\n");
+		syslog(LOG_ERR, _("exec error: %m\n"));
 		close(fd[0]);
 		exit(1);
 	}
